==> green-core-1.77.0.tgz: package/components/checkbox/checkbox.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleClick, _handleKeyDown, _toggleChecked, toggleChecked_fn;
import { property, query } from "lit/decorators.js";
import { GdsToggleControlBase } from "../../primitives/toggle-controls-base/toggle-control-base.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import rbcbToggleStyles from "../../shared-styles/rbcb-toggle.style.js";
import { checkboxToggle } from "../../shared-styles/rbcb-toggle.template";
import { tokens } from "../../tokens.style.js";
import { watch } from "../../utils/decorators/watch.js";
import { GdsFormControlElement } from "../form/form-control.js";
import { IconCheckmark } from "../pure.js";
import { styles } from "./checkbox.styles.js";
let GdsCheckbox = class extends GdsFormControlElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _toggleChecked);
    this.label = "";
    this.supportingText = "";
    this.checked = false;
    this.indeterminate = false;
    this.disabled = false;
    __privateAdd(this, _handleClick, (e) => {
      this.focus();
      __privateMethod(this, _toggleChecked, toggleChecked_fn).call(this);
    });
    __privateAdd(this, _handleKeyDown, (e) => {
      if (this.disabled)
        return;
      if (e.key === "Enter" || e.key === " ") {
        e.preventDefault();
        __privateMethod(this, _toggleChecked, toggleChecked_fn).call(this);
      }
    });
  }
  get value() {
    return this._internalValue || "";
  }
  set value(value) {
    this._internalValue = value;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "checkbox");
    this._updateAriaState();
    this.addEventListener("keydown", __privateGet(this, _handleKeyDown));
    this.addEventListener("click", __privateGet(this, _handleClick));
  }
  _updateAriaState() {
    this.setAttribute(
      "aria-checked",
      this.indeterminate ? "mixed" : this.checked.toString()
    );
    this.setAttribute("aria-disabled", this.disabled.toString());
    this.setAttribute("tabindex", this.disabled ? "-1" : "0");
    this.toggleAttribute("aria-invalid", this.invalid);
  }
  _handleIndeterminateChange() {
    if (this.indeterminate) {
      this.checked = false;
    }
  }
  updated(changedProperties) {
    super.updated(changedProperties);
    if (changedProperties.has("checked") || changedProperties.has("indeterminate") || changedProperties.has("disabled") || changedProperties.has("invalid")) {
      this._updateAriaState();
    }
  }
  render() {
    return html`
      <gds-toggle-control-base
        supporting-text=${this.supportingText}
        label=${this.label}
        type="checkbox"
      >
        ${checkboxToggle({
      checked: this.checked,
      indeterminate: this.indeterminate,
      disabled: this.disabled,
      invalid: this.invalid
    })}
      </gds-toggle-control-base>
    `;
  }
  _getValidityAnchor() {
    return this._elCheckbox || this;
  }
  formResetCallback() {
    this.checked = false;
  }
};
_handleClick = new WeakMap();
_handleKeyDown = new WeakMap();
_toggleChecked = new WeakSet();
toggleChecked_fn = function() {
  if (this.indeterminate) {
    this.indeterminate = false;
    this.checked = true;
  } else {
    this.checked = !this.checked;
  }
  this.dispatchEvent(
    new Event("change", {
      bubbles: true,
      composed: true
    })
  );
  this.dispatchEvent(
    new Event("input", {
      bubbles: true,
      composed: true
    })
  );
};
GdsCheckbox.styles = [tokens, rbcbToggleStyles, styles];
__decorateClass([
  property()
], GdsCheckbox.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsCheckbox.prototype, "supportingText", 2);
__decorateClass([
  property({ type: Boolean })
], GdsCheckbox.prototype, "checked", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsCheckbox.prototype, "indeterminate", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsCheckbox.prototype, "disabled", 2);
__decorateClass([
  query(".rbcb")
], GdsCheckbox.prototype, "_elCheckbox", 2);
__decorateClass([
  watch("indeterminate")
], GdsCheckbox.prototype, "_handleIndeterminateChange", 1);
GdsCheckbox = __decorateClass([
  gdsCustomElement("gds-checkbox", {
    dependsOn: [GdsToggleControlBase, IconCheckmark]
  })
], GdsCheckbox);
export {
  GdsCheckbox
};

==> green-core-1.79.0.tgz: package/components/checkbox/checkbox.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleClick, _handleKeyDown, _toggleChecked, toggleChecked_fn;
import { property, query } from "lit/decorators.js";
import { GdsToggleControlBase } from "../../primitives/toggle-controls-base/toggle-control-base.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import rbcbToggleStyles from "../../shared-styles/rbcb-toggle.style.js";
import { checkboxToggle } from "../../shared-styles/rbcb-toggle.template.js";
import { tokens } from "../../tokens.style.js";
import { watch } from "../../utils/decorators/watch.js";
import { GdsFormControlElement } from "../form/form-control.js";
import { IconCheckmark } from "../pure.js";
import { styles } from "./checkbox.styles.js";
let GdsCheckbox = class extends GdsFormControlElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _toggleChecked);
    this.label = "";
    this.supportingText = "";
    this.checked = false;
    this.indeterminate = false;
    this.disabled = false;
    __privateAdd(this, _handleClick, (e) => {
      this.focus();
      __privateMethod(this, _toggleChecked, toggleChecked_fn).call(this);
    });
    __privateAdd(this, _handleKeyDown, (e) => {
      if (this.disabled)
        return;
      if (e.key === "Enter" || e.key === " ") {
        e.preventDefault();
        __privateMethod(this, _toggleChecked, toggleChecked_fn).call(this);
      }
    });
  }
  get value() {
    return this._internalValue || "";
  }
  set value(value) {
    this._internalValue = value;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "checkbox");
    this._updateAriaState();
    this.addEventListener("keydown", __privateGet(this, _handleKeyDown));
    this.addEventListener("click", __privateGet(this, _handleClick));
  }
  _updateAriaState() {
    this.setAttribute(
      "aria-checked",
      this.indeterminate ? "mixed" : this.checked.toString()
    );
    this.setAttribute("aria-disabled", this.disabled.toString());
    this.setAttribute("tabindex", this.disabled ? "-1" : "0");
    this.toggleAttribute("aria-invalid", this.invalid);
  }
  _handleIndeterminateChange() {
    if (this.indeterminate) {
      this.checked = false;
    }
  }
  updated(changedProperties) {
    super.updated(changedProperties);
    if (changedProperties.has("checked") || changedProperties.has("indeterminate") || changedProperties.has("disabled") || changedProperties.has("invalid")) {
      this._updateAriaState();
    }
  }
  render() {
    return html`
      <gds-toggle-control-base
        supporting-text=${this.supportingText}
        label=${this.label}
        type="checkbox"
      >
        ${checkboxToggle({
      checked: this.checked,
      indeterminate: this.indeterminate,
      disabled: this.disabled,
      invalid: this.invalid
    })}
      </gds-toggle-control-base>
    `;
  }
  _getValidityAnchor() {
    return this._elCheckbox || this;
  }
  formResetCallback() {
    this.checked = false;
  }
};
_handleClick = new WeakMap();
_handleKeyDown = new WeakMap();
_toggleChecked = new WeakSet();
toggleChecked_fn = function() {
  if (this.indeterminate) {
    this.indeterminate = false;
    this.checked = true;
  } else {
    this.checked = !this.checked;
  }
  this.dispatchEvent(
    new Event("change", {
      bubbles: true,
      composed: true
    })
  );
  this.dispatchEvent(
    new Event("input", {
      bubbles: true,
      composed: true
    })
  );
};
GdsCheckbox.styles = [tokens, rbcbToggleStyles, styles];
__decorateClass([
  property()
], GdsCheckbox.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsCheckbox.prototype, "supportingText", 2);
__decorateClass([
  property({ type: Boolean })
], GdsCheckbox.prototype, "checked", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsCheckbox.prototype, "indeterminate", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsCheckbox.prototype, "disabled", 2);
__decorateClass([
  query(".rbcb")
], GdsCheckbox.prototype, "_elCheckbox", 2);
__decorateClass([
  watch("indeterminate")
], GdsCheckbox.prototype, "_handleIndeterminateChange", 1);
GdsCheckbox = __decorateClass([
  gdsCustomElement("gds-checkbox", {
    dependsOn: [GdsToggleControlBase, IconCheckmark]
  })
], GdsCheckbox);
export {
  GdsCheckbox
};
